@@ -1,5 +1,6 @@
 from django.db import models
 import json
+from django.conf import settings
 
 
 class TemplateData(models.Model):
@@ -17,6 +18,7 @@ class TemplateData(models.Model):
     
     key = models.CharField(max_length=255)
     page = models.CharField(max_length=100, default='global')
+    lang = models.CharField(max_length=100, default='en', choices=settings.LANGUAGES)
     inherit_page = models.CharField(max_length=100, null=True, blank=True)
     description = models.CharField(max_length=255, null=True, blank=True)
     value = models.TextField(null=True, blank=True)
